lrcalc_python: Littlewood-Richardson calculator
===============================================

Description
-----------

Python bindings for the Littlewood-Richardson Calculator

http://sites.math.rutgers.edu/~asbuch/lrcalc/

License
-------

GNU General Public License V3


Upstream Contact
----------------

Anders S. Buch (asbuch@math.rutgers.edu)

https://bitbucket.org/asbuch/lrcalc
